Crate kcr_ipam_cluster_x_k8s_io

Crate kcr_ipam_cluster_x_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the ipam.cluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

ipam.cluster.x-k8s.io/v1alpha1

  • IPAddressClaim
  • IPAddress

ipam.cluster.x-k8s.io/v1beta1

  • IPAddressClaim
  • IPAddress

ipam.cluster.x-k8s.io/v1beta2

  • IPAddressClaim
  • IPAddress

Modules

v1alpha1
v1beta1
v1beta2