This crate contains kube-rs compatible bindings for Kubernetes custom resources for the ipam.cluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
ipam.cluster.x-k8s.io/v1alpha1
IPAddressClaimIPAddress
ipam.cluster.x-k8s.io/v1beta1
IPAddressClaimIPAddress
ipam.cluster.x-k8s.io/v1beta2
IPAddressClaimIPAddress